@@ -1,7 +1,7 @@
 from datetime import datetime as datetime
 from typing import Optional  # noqa
 
-from lnschema_bionty import featureset  # noqa
+from lnschema_bionty import featureset, species  # noqa
 from sqlmodel import Field, SQLModel
 
 
@@ -35,6 +35,7 @@ class biometa(SQLModel, table=True):  # type: ignore
     biosample_id: int = Field(default=None, foreign_key="biosample.id")
     readout_type_id: int = Field(default=None, foreign_key="readout_type.id")
     featureset_id: int = Field(default=None, foreign_key="featureset.id")
+    experiment_id: int = Field(default=None, foreign_key="experiment.id")
 
 
 class biosample(SQLModel, table=True):  # type: ignore
@@ -42,15 +43,32 @@ class biosample(SQLModel, table=True):  # type: ignore
 
     id: Optional[int] = Field(default=None, primary_key=True)
     name: str = Field(index=True)
-    species_id: str = Field(default=None, foreign_key="species.id")
+    species_id: int = Field(default=None, foreign_key="species.id")
 
 
 class readout_type(SQLModel, table=True):  # type: ignore
-    """Readouts of experiments."""
+    """Readout type of experiments."""
 
-    id: Optional[int] = Field(default=None, primary_key=True)
+    id: Optional[str] = Field(default=None, primary_key=True)
     efo_id: str = Field(default=None, index=True)
     name: str = Field(default=None, index=True)
     molecule: str = Field(default=None)
     instrument: str = Field(default=None)
     measurement: str = Field(default=None)
+
+
+class experiment(SQLModel, table=True):  # type: ignore
+    """Experiments."""
+
+    id: Optional[int] = Field(default=None, primary_key=True)
+    name: str = Field(default=None)
+    project: str = Field(default=None)
+    experiment_type_id: int = Field(default=None, foreign_key="experiment_type.id")
+
+
+class experiment_type(SQLModel, table=True):  # type: ignore
+    """Experiment types."""
+
+    id: Optional[int] = Field(default=None, primary_key=True)
+    name: str = Field(default=None)
+    efo_id: str = Field(default=None)
